export default {
	filteredItems: () => {
		// Get the data from the query
		const allItems = get_foss_items.data.data;
		// Get selected categories from the multi-select widget
		const selectedCategories = MultiSelectCategory.selectedOptionLabels;
		// Get selected target markets from the multi-select widget
		const selectedTargetMarkets = MultiSelectTargetMarket.selectedOptionValues;
		// Get selected certification options
		const selectedCertifications = MultiSelectCertification.selectedOptionLabels;

		// If no categories selected, return empty array
		if (!selectedCategories || selectedCategories.length === 0) {
			return [];
		}

		// If no target markets selected, return empty array
		if (!selectedTargetMarkets || selectedTargetMarkets.length === 0) {
			return [];
		}

		// If no certifications selected, return empty array
		if (!selectedCertifications || selectedCertifications.length === 0) {
			return [];
		}

		// Filter items based on category, target_market, and certification
		return allItems.filter(item => {
			// Check if at least one category matches
			const categoryMatch = item.category.some(cat => 
																							 selectedCategories.includes(cat)
																							);

			// Check if at least one target market matches
			const targetMarketMatch = item.target_market.some(tm => 
																												selectedTargetMarkets.includes(tm)
																											 );

			// Certification logic
			const certifiedSelected = selectedCertifications.includes("Certified");
			const notCertifiedSelected = selectedCertifications.includes("Not Certified");
			let certificationMatch;

			// If both selected, match all items (no filtering)
			if (certifiedSelected && notCertifiedSelected) {
				certificationMatch = true;
			}
			// If only "certified" selected, match true only
			else if (certifiedSelected) {
				certificationMatch = item.certified === true;
			}
			// If only "not certified" selected, match false only
			else if (notCertifiedSelected) {
				certificationMatch = item.certified === false;
			}

			// Item must match all conditions
			return categoryMatch && targetMarketMatch && certificationMatch;
		});
	}
}